"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeycloakVerifyProvider = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const repositories_1 = require("../../../repositories");
const auth_user_model_1 = require("../models/auth-user.model");
const providers_1 = require("../../../providers");
let KeycloakVerifyProvider = class KeycloakVerifyProvider {
    constructor(userRepository, userCredsRepository, signupProvider, preVerifyProvider, postVerifyProvider) {
        this.userRepository = userRepository;
        this.userCredsRepository = userCredsRepository;
        this.signupProvider = signupProvider;
        this.preVerifyProvider = preVerifyProvider;
        this.postVerifyProvider = postVerifyProvider;
    }
    value() {
        return async (accessToken, refreshToken, profile) => {
            let user = await this.userRepository.findOne({
                where: {
                    email: profile.email,
                },
            });
            user = await this.preVerifyProvider(accessToken, refreshToken, profile, user);
            if (!user) {
                const newUser = await this.signupProvider(profile);
                if (newUser) {
                    user = newUser;
                }
                else {
                    throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
                }
            }
            const creds = await this.userCredsRepository.findOne({
                where: {
                    userId: user.id,
                },
            });
            if (!creds ||
                creds.authProvider !== 'keycloak' ||
                creds.authId !== profile.keycloakId) {
                throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
            }
            const authUser = new auth_user_model_1.AuthUser({
                ...user,
                id: user.id,
            });
            authUser.permissions = [];
            authUser.externalAuthToken = accessToken;
            authUser.externalRefreshToken = refreshToken;
            return this.postVerifyProvider(profile, authUser);
        };
    }
};
KeycloakVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, repository_1.repository(repositories_1.UserRepository)),
    tslib_1.__param(1, repository_1.repository(repositories_1.UserCredentialsRepository)),
    tslib_1.__param(2, context_1.inject(providers_1.SignUpBindings.KEYCLOAK_SIGN_UP_PROVIDER)),
    tslib_1.__param(3, context_1.inject(providers_1.VerifyBindings.KEYCLOAK_PRE_VERIFY_PROVIDER)),
    tslib_1.__param(4, context_1.inject(providers_1.VerifyBindings.KEYCLOAK_POST_VERIFY_PROVIDER)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.UserRepository,
        repositories_1.UserCredentialsRepository, Function, Function, Function])
], KeycloakVerifyProvider);
exports.KeycloakVerifyProvider = KeycloakVerifyProvider;
//# sourceMappingURL=keycloak-verify.provider.js.map